Clojure only.

knossos.memory

Helps manage memory pressure

Helps manage memory pressure
raw docstring

fracclj

source

on-low-mem!clj

(on-low-mem! f)

Invokes f when less than frac memory is free after GC. Globally mutates a MemoryPoolMXBean. Returns a zero-arity function that, when called, cancels the callback.

Invokes f when less than frac memory is free after GC. Globally mutates a
MemoryPoolMXBean. Returns a zero-arity function that, when called, cancels
the callback.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries