Helps manage memory pressure
Helps manage memory pressure
(on-low-mem! f)Invokes f when less than frac memory is free after GC. Globally mutates a MemoryPoolMXBean. Returns a zero-arity function that, when called, cancels the callback.
Invokes f when less than frac memory is free after GC. Globally mutates a MemoryPoolMXBean. Returns a zero-arity function that, when called, cancels the callback.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |